@@ -8,7 +8,11 @@ from reactivex.observable import ConnectableObservable
 from reactivex.disposable import CompositeDisposable
 from reactivex.scheduler import ThreadPoolScheduler
 from elm_framework_helpers.websockets import models
-from bittrade_huobi_websocket.models.rest import market_depth, get_all_open_orders, order_details
+from bittrade_huobi_websocket.models.rest import (
+    market_depth,
+    get_all_open_orders,
+    order_details,
+)
 from bittrade_huobi_websocket.models import UserFeedMessage, HttpResponse
 
 from bittrade_huobi_websocket.models.rest.cancel_orders_batch import (
@@ -19,9 +23,7 @@ from bittrade_huobi_websocket.models.rest.create_order import (
     OrderCreateParams,
     OrderCreateResponse,
 )
-from bittrade_huobi_websocket.models.rest.cancel_order import (
-    CancelOrderParams
-)
+from bittrade_huobi_websocket.models.rest.cancel_order import CancelOrderParams
 
 
 class BookConfig(NamedTuple):
@@ -37,20 +39,22 @@ class FrameworkContext:
     cancel_all_http: Callable[
         [Optional[CancelOrdersBatchParams]], Observable[CancelOrdersBatchData]
     ]
-    cancel_order_http: Callable[
-        [CancelOrderParams], Observable[bool]
-    ]
+    cancel_order_http: Callable[[CancelOrderParams], Observable[bool]]
     create_order_http: Callable[
         [OrderCreateParams],
         Observable[OrderCreateResponse],
     ]
     get_book_http: Callable[
-        [market_depth.MarketDepthParams], Observable[market_depth.MarketDepthResponse]
+        [market_depth.MarketDepthParams], Observable[HttpResponse]
     ]
     get_account_balance_http: Callable[
         [str], Observable[HttpResponse]
     ]
     exchange: huobi
+    load_all_open_orders: Callable[
+        [get_all_open_orders.AllOpenOrdersParams],
+        Observable[list[get_all_open_orders.AllOpenOrder]],
+    ]
     public_socket_connection: ConnectableObservable[models.WebsocketBundle]
     private_socket_connection: ConnectableObservable[models.WebsocketBundle]
     private_messages: Observable[UserFeedMessage]
@@ -58,6 +62,6 @@ class FrameworkContext:
     websocket_bs: models.EnhancedWebsocketBehaviorSubject
     open_orders_http: Callable[
         [get_all_open_orders.AllOpenOrdersParams],
-        Observable[get_all_open_orders.AllOpenOrdersResponse],
+        Observable[HttpResponse],
     ]
     order_details_http: Callable[[str], Observable[HttpResponse]]
